@@ -14,7 +14,7 @@ void gen_compMat(mat& Cm, const mat& A, const int M, const int p);
 
 double get_ar(mat& Y, int p);
 
-void get_Vminnesota(mat& V, vec& sigmas, double shrink1, double shrink2, double shrink3, double shrink4, bool cons, int Mstar, int p, bool trend);
+void get_Vminnesota(mat& V, vec& sigmas, double shrink1, double shrink2, double shrink3, double shrink4, bool cons, int Mstar, int plag, int plagstar, bool trend);
 
 void inplace_tri_mat_mult(arma::rowvec &x, arma::mat const &trimat);
 
@@ -22,8 +22,4 @@ arma::vec dmvnrm_arma_fast(const arma::mat& x, const arma::mat& mean, const arma
 
 arma::vec dmvnrm_arma_old(arma::mat& x, arma::mat& mean, arma::mat& sigma, bool logd = false);
 
-void get_PHI(arma::cube& PHI, arma::cube& Fmat, const int nhor);
-
-void get_nullspace(arma::mat& NU, arma::mat& M);
-
 #endif
